@@ -73,7 +73,7 @@
 /*
  * Newly created text documents have an empty URL and a non-empty document name.
  */
- 
+
 /*
  * WARNING: Several methods in the document manager can open dialogs and consequently
  *          launch a new event loop. It is therefore possible that the auto save feature
@@ -132,6 +132,20 @@ Manager::~Manager()
 	}
 }
 
+void Manager::readConfig()
+{
+	if(m_editor) {
+		m_editor->readConfig(KGlobal::config().data());
+	}
+}
+
+void Manager::writeConfig()
+{
+	if(m_editor) {
+		m_editor->writeConfig(KGlobal::config().data());
+	}
+}
+
 void Manager::trashDoc(TextInfo *docinfo, KTextEditor::Document *doc /*= NULL */ )
 {
 	KILE_DEBUG() << "==void Manager::trashDoc(" << docinfo->url().toLocalFile() << ")=====";
@@ -882,18 +896,7 @@ bool Manager::fileSaveAll(bool amAutoSaving, bool disUntitled)
 				if(amAutoSaving && fi.size() > 0) { // the size check ensures that we don't save empty files (to prevent something like #125809 in the future).
 					KUrl backupUrl = KUrl(url.toLocalFile()+ ".backup");
 
-				 	// patch for secure permissions, slightly modified for kile by Thomas Braun, taken from #103331
-
-					// get the right permissions, start with safe default
-					mode_t  perms = 0600;
-					KIO::UDSEntry fentry;
-					if (KIO::NetAccess::stat (url, fentry, m_ki->mainWindow())) {
-						KILE_DEBUG () << "stating successful: " << url.prettyUrl();
-						KFileItem item (fentry, url);
-						perms = item.permissions();
-					}
-
-					// first del existing file if any, than copy over the file we have
+					// first del existing file if any, then copy over the file we have
 					// failure if a: the existing file could not be deleted, b: the file could not be copied
 					if((!KIO::NetAccess::exists( backupUrl, false, m_ki->mainWindow())
 					   || KIO::NetAccess::del( backupUrl, m_ki->mainWindow()))
@@ -1738,8 +1741,8 @@ bool Manager::projectCloseAll()
 	Locker lock(&m_autoSaveLock);
 	KILE_DEBUG() << "==Kile::projectCloseAll==========================";
 
-	for(QList<KileProject*>::iterator it = m_projects.begin(); it != m_projects.end(); ++it) {
-		if(!projectClose((*it)->url())) {
+	while(m_projects.size() > 0) {
+		if(!projectClose(m_projects.first()->url())) {
 			return false;
 		}
 	}
@@ -1924,7 +1927,7 @@ void Manager::reloadXMLOnAllDocumentsAndViews()
 			continue;
 		}
 		doc->reloadXML();
-		QList<KTextEditor::View*> views = doc->views(); 
+		QList<KTextEditor::View*> views = doc->views();
 		for(QList<KTextEditor::View*>::iterator viewIt = views.begin(); viewIt != views.end(); ++viewIt) {
 			(*viewIt)->reloadXML();
 		}
